"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseFactory = void 0;
const MemberInitializer_1 = require("../MemberInitializer");
const Field_1 = require("../members/Field");
const Method_1 = require("../members/Method");
const Signal_1 = require("../members/Signal");
class BaseFactory {
    constructor(regex) {
        this._regex = regex;
    }
    handles(nameDefinition) {
        return this._regex.test(nameDefinition);
    }
    createMember(accessModifier, nameDefinition, body) {
        return BaseFactory.createMemberFrom(accessModifier, nameDefinition, body);
    }
    static createMemberFrom(accessModifier, nameDefinition, body) {
        let memberInitializer = new MemberInitializer_1.MemberInitializer();
        if (nameDefinition.indexOf("()") != -1) {
            memberInitializer.isMethod = true;
            memberInitializer.isVirtual = true;
            let typeRegex = /\(\)\s*(?:\:\s*(.+)\s*)?$/;
            let result = typeRegex.exec(nameDefinition);
            if (result[1]) {
                memberInitializer.type = result[1];
            }
            nameDefinition = nameDefinition.replace(typeRegex, "");
        }
        let names = nameDefinition.split(/\s+/);
        memberInitializer.name = names[names.length - 1];
        for (let i = 0; i < names.length - 1; i++) {
            if ("final" === names[i]) {
                memberInitializer.isVirtual = false;
            }
            if ("static" === names[i]) {
                memberInitializer.isStatic = true;
            }
            if ("signal" === names[i]) {
                memberInitializer.isSignal = true;
            }
        }
        let member = null;
        if (memberInitializer.isMethod) {
            if (memberInitializer.isSignal) {
                member = new Signal_1.Signal(memberInitializer);
            }
            else {
                member = new Method_1.Method(memberInitializer);
            }
        }
        else {
            member = new Field_1.Field(memberInitializer);
        }
        member.accessModifier = accessModifier;
        member.parseBody(body);
        return member;
    }
}
exports.BaseFactory = BaseFactory;
//# sourceMappingURL=BaseFactory.js.map